----------------------------------------------------------------------------------
-- Engineer: Catherine Lagunzad
-- Create Date: 11/20/2017 12:21:09 PM
-- Description: LED indicates which player receives the question and
-- disables the buzzers of the other players
---------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;


entity player_lockout_LED is
    Port ( player1 : in STD_LOGIC;
           player2 : in STD_LOGIC;
           reset : in STD_LOGIC;
           CLK : in STD_LOGIC;
           player_LED : out STD_LOGIC_VECTOR (1 downto 0));
end player_lockout_LED;

architecture Behavioral of player_lockout_LED is
    type state_type is (ST0, ST1, ST2);
    signal PS, NS: state_type;
begin
    sync_proc : process (reset, CLK, NS)
    begin
        if (reset = '1') then           --asynchronous
            PS <= ST0;
        elsif (rising_edge(CLK)) then   --synchronous
            PS <= NS;
        end if;
    end process;
    
    comb_proc : process (PS, player1, player2)
    begin
        case PS is
            when ST0 =>                                         --initial state
                if (player1 = '0' AND player2 = '0') then
                    NS <= ST0;
                elsif (player1 = '1' AND player2 = '0') then    --player1 buzzes first
                    NS <= ST1;
                elsif (player1 = '0' AND player2 = '1') then    --player2 buzzes first
                    NS <= ST2;
                end if;
                
            when ST1 =>                                         --player1's LED is active
                if (player1 = '1' AND player2 = '1') then
                    NS <= ST1;
                elsif (player1 = '1' AND player2 = '0') then
                    NS <= ST1;
                end if;
                
            when ST2 =>                                         --player2's LED is active
                if (player1 ='1' AND player2 = '1') then
                    NS <= ST2;
                elsif (player1 = '0' AND player2 = '1') then
                    NS <= ST2;
                end if;
            when others =>
                NS <= ST0;
        end case;
    end process;

with PS select
    player_LED <= "00" when ST0,
                  "01" when ST1,
                  "10" when ST2,
                  "00" when others;
end Behavioral;

